pub fn derive_project(
sessions: &[CursorSession],
config: &DeriveConfig,
) -> Vec<Path>Expand description
Derive a Path from each of several Cursor sessions.
pub fn derive_project(
sessions: &[CursorSession],
config: &DeriveConfig,
) -> Vec<Path>Derive a Path from each of several Cursor sessions.